
# Slot: entity negatively regulated by entity




URI: [biolink:entity_negatively_regulated_by_entity](https://w3id.org/biolink/vocab/entity_negatively_regulated_by_entity)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [entity regulated by entity](entity_regulated_by_entity.md)

## Children


## Used by

